import pyttsx3
import speech_recognition as sr
import datetime

lst = [0,1,2,3,4,5,6,7]
engine = pyttsx3.init('sapi5')
voices = engine.getProperty('voices')
#print(voices[0].id)
engine.setProperty('voices',voices[0].id)

# text to speech
def speak(audio):
    engine.say(audio)
    print(audio)
    engine.runAndWait()

# to convert voice into text
def listen():
    r = sr.Recognizer()
    with sr.Microphone() as source:
        print("listening...")
        r.pause_threshold = 1
        audio = r.listen(source,phrase_time_limit=5)
    try:
        print("Recognizing...")
        query = r.recognize_google(audio, language='en-in')
        print(f"user said: {query}")

    except Exception as e:
        print("say that again please...")
        return"none"
    return query

# to wish
def wish():
    hour = int(datetime.datetime.now().hour)
    if hour>=0 and hour<12:
        speak("good morning")
    elif hour>=12 and hour<18:
        speak("good afternoon")
    else:
        speak("good evening")
    # speak("i am jarvis sir. please tell me how can i help you")


from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = 'A simple python library to wish, listen and speak'

with open("README.md", "r") as fh:
    LONG_DESCRIPTION = fh.read()

# Setting up
setup(
    name="twoSenses",
    version=VERSION,
    author="Gautam Yadav",
    author_email="gautamdiscoder@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    url="https://github.com/gautamdis/Senses_2",
    packages=find_packages(),
    install_requires=['pyttsx3','SpeechRecognition','datetime'],
    py_modules=['twoSenses'],
    python_requires='>=3.6',
    keywords=['twosenses', 'Twosenses', 'twoSenses', 'TwoSenses', 'speaking', 'listening', 'wishing', 'python', 'python3', 'jarvis', 'siri', 'alexa', 'google assistant', 'voice', 'voice assistant', 'voice recognition', 'speech recognition', 'text to speech', 'speech to text', 'Gautam Yadav', 'Gautam', 'Yadav', 'gautamdiscoder'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
